Query filter
============

![image](icons/queryfilter.svg)

Query a corpus 

Signals
-------

- Corpus

**Outputs**:

- Corpus

Description
-----------

Query a corpus to count occurrences or to filter a corpus